@@ -5,15 +5,18 @@ sigma.hat.lm <- function(object){
 }
 
 
-sigma.hat.glm <- function(object){
+sigma.hat.glm <- function (object){
+    dispersion <- if (is.null(object$dispersion))
+        summary(object)$dispersion
+    else object$dispersion
     object.class <- class(object)[[1]]
-    if(object$family$family=="gaussian"){
-        sigma <- sqrt(summary(object)$dispersion)
+    if (object$family$family == "gaussian") {
+        sigma <- sqrt(dispersion)
     }
     else {
-        sigma <- summary(object, correlation=TRUE)$sigma
+        sigma <- summary(object, correlation = TRUE)$sigma
     }
-    return (sigma)
+    return(sigma)
 }
 
 
